#include <stdlib.h>
//C Standard General Utilities Library, more info here: http://www.cplusplus.com/reference/clibrary/cstdlib/
#include <GLUT/glut.h>
//GLUT library, take note that when trying out examples you find on the web you might need to change this as on windows and linux
//this is called <GL/glut.h>

//I'm declaring my function prototypes here, otherwise the compiler will complain we use an 'Undeclared Identifier' in the main function.
//Another way to solve this is to have your display, reshape, idle,etc...functions before the main function. I just prefer it this way.
//We will use the boolean fullScreen to toggle between fullscreen and windowed mode.
void display();
void reshape(int width, int height);
void idle();
void keyb(unsigned char key, int x, int y);
bool fullScreen = false;

//Main Loop
int main(int argc, char** argv)
{
	glutInit(&argc, argv);
    //argc is the number of variables passed to our program, argv is a pointer to those arguments,
    //they are passed to glut here. There's no need to know more about this right now.
    
	glutInitDisplayMode(GLUT_RGBA | GLUT_DOUBLE | GLUT_DEPTH);
    /*As the name says, this line initializes the display mode.
     -GLUT_RGBA states we want color and alpha buffers for our window
     -GLUT_DOUBLE means we want a Double Buffer, this means that images are completely drawn before they are sent
     to the screen. This will prevent flickering images.
     -GLUT_DEPTH means that we want a Depth Buffer. This will allow for the images to be drawn correctly with respect
     to their distance: i.e. objects closeby will overlap objects further away.*/
    
	glutInitWindowSize(640, 480);
    //Define the size we would like the window to be
    
	glutCreateWindow("window_name");
    //This command creates the window with the specifications we've set before and gives it a name. 
    
	glutDisplayFunc(display);
    //this function is called whenever GLUT decides it's time to redraw the contents of the current window, it's also
    //the function where we'll do our drawing.
    glutReshapeFunc(reshape);
    //this function is called whenever the user changes the size of the frame
    glutIdleFunc(idle);
    //this function is called whenever glut is not doing anything
    glutKeyboardFunc(keyb);
    //this function is called when a key is pressed
	glutMainLoop();
    //glutMainLoop() goes on forever and ever until you quit the program.
}

//Idle Function
void idle(void)
{
}

//Reshape Function
void reshape(int width, int height)
{
    glViewport(0, 0, width, height);
	glMatrixMode(GL_PROJECTION);
	glLoadIdentity();
	gluPerspective(45.,(GLfloat) width/(GLfloat) height,0.1, 800.0);
	gluLookAt(0.0,0.0,5.0, 0.0, 0.0, 0.0, 0,1,0);
    glMatrixMode(GL_MODELVIEW);
	
}
//Display Function, this function simply clears the color and depth buffers and then swaps buffers (remember the double buffered
//display mode we set)
void display(void)
{
    glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
    glutWireSphere(0.5,100,100);//draw a wireframe sphere.
    glutSwapBuffers();
}

//Keyboard Function
//When pressing the 'esc' key, the boolean changes from false to true or from true to false. The if statement
//checks what the value of fullScreen is, and changes to fullscreen-mode if true and back to windowed mode if false.
void keyb(unsigned char key, int x, int y){
	switch (key){
		case 27:
            fullScreen = !fullScreen;
            if (fullScreen) {
                glutFullScreen();
            }
            else {
                glutReshapeWindow(640, 480);
                glutPositionWindow(100, 100);
            }
            break;
	}
}